@@ -56,9 +56,6 @@ FAILEDOPERATION_INSTANCESTATUSNOTINRUNING = 'FailedOperation.InstanceStatusNotIn
 # Invalid listener protocol.
 FAILEDOPERATION_INVALIDLISTENERPROTOCOL = 'FailedOperation.InvalidListenerProtocol'
 
-# Limit on the number of domain names exceeded.
-FAILEDOPERATION_LIMITNUMOFDOMAINS = 'FailedOperation.LimitNumofDomains'
-
 # Limit on the number of listeners exceeded.
 FAILEDOPERATION_LIMITNUMOFLISTENER = 'FailedOperation.LimitNumofListener'
 
@@ -140,6 +137,12 @@ INVALIDPARAMETER = 'InvalidParameter'
 # Incorrect parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# The domain name is blocked for ICP issues.
+INVALIDPARAMETERVALUE_DOMAININICPBLACKLIST = 'InvalidParameterValue.DomainInIcpBlacklist'
+
+# The domain name does not have an ICP filing.
+INVALIDPARAMETERVALUE_DOMAINNOTREGISTER = 'InvalidParameterValue.DomainNotRegister'
+
 # The `RealServer` already exists.
 INVALIDPARAMETERVALUE_DUPLICATERS = 'InvalidParameterValue.DuplicateRS'
 
